depends = ('ITKPyBase', 'ITKTransform', )
templates = (
  ('Mesh', 'itk::Mesh', 'itkMeshSS2', True, 'signed short,2'),
  ('Mesh', 'itk::Mesh', 'itkMeshUC2', True, 'unsigned char,2'),
  ('Mesh', 'itk::Mesh', 'itkMeshUS2', True, 'unsigned short,2'),
  ('Mesh', 'itk::Mesh', 'itkMeshF2', True, 'float,2'),
  ('Mesh', 'itk::Mesh', 'itkMeshD2', True, 'double,2'),
  ('Mesh', 'itk::Mesh', 'itkMeshSS3', True, 'signed short,3'),
  ('Mesh', 'itk::Mesh', 'itkMeshUC3', True, 'unsigned char,3'),
  ('Mesh', 'itk::Mesh', 'itkMeshUS3', True, 'unsigned short,3'),
  ('Mesh', 'itk::Mesh', 'itkMeshF3', True, 'float,3'),
  ('Mesh', 'itk::Mesh', 'itkMeshD3', True, 'double,3'),
  ('CellTraitsInfo', 'itk::CellTraitsInfo', 'itkCellTraitsInfo2FFULLULLULLPF2MCULLPF2', False, '2,float,float,unsigned long long,unsigned long long,unsigned long long,itk::Point< float,2 >,itk::MapContainer< unsigned long long,itk::Point< float,2 > >, std::set< unsigned long long >'),
  ('CellTraitsInfo', 'itk::CellTraitsInfo', 'itkCellTraitsInfo2FFULLULLULLPF2VCULLPF2', False, '2,float,float,unsigned long long,unsigned long long,unsigned long long,itk::Point< float,2 >,itk::VectorContainer< unsigned long long,itk::Point< float,2 > >, std::set< unsigned long long >'),
  ('CellTraitsInfo', 'itk::CellTraitsInfo', 'itkCellTraitsInfo3FFULLULLULLPF3MCULLPF3', False, '3,float,float,unsigned long long,unsigned long long,unsigned long long,itk::Point< float,3 >,itk::MapContainer< unsigned long long,itk::Point< float,3 > >, std::set< unsigned long long >'),
  ('CellTraitsInfo', 'itk::CellTraitsInfo', 'itkCellTraitsInfo3FFULLULLULLPF3VCULLPF3', False, '3,float,float,unsigned long long,unsigned long long,unsigned long long,itk::Point< float,3 >,itk::VectorContainer< unsigned long long,itk::Point< float,3 > >, std::set< unsigned long long >'),
  ('CellInterface', 'itk::CellInterface', 'itkCellInterfaceSSCTI2FFULLULLULLPF2MCULLPF2', False, 'signed short,itk::CellTraitsInfo< 2,float,float,unsigned long long,unsigned long long,unsigned long long,itk::Point< float,2 >,itk::MapContainer< unsigned long long,itk::Point< float,2 > >, std::set< unsigned long long > >'),
  ('CellInterface', 'itk::CellInterface', 'itkCellInterfaceSSCTI2FFULLULLULLPF2VCULLPF2', False, 'signed short,itk::CellTraitsInfo< 2,float,float,unsigned long long,unsigned long long,unsigned long long,itk::Point< float,2 >,itk::VectorContainer< unsigned long long,itk::Point< float,2 > >, std::set< unsigned long long > >'),
  ('CellInterface', 'itk::CellInterface', 'itkCellInterfaceUCCTI2FFULLULLULLPF2MCULLPF2', False, 'unsigned char,itk::CellTraitsInfo< 2,float,float,unsigned long long,unsigned long long,unsigned long long,itk::Point< float,2 >,itk::MapContainer< unsigned long long,itk::Point< float,2 > >, std::set< unsigned long long > >'),
  ('CellInterface', 'itk::CellInterface', 'itkCellInterfaceUCCTI2FFULLULLULLPF2VCULLPF2', False, 'unsigned char,itk::CellTraitsInfo< 2,float,float,unsigned long long,unsigned long long,unsigned long long,itk::Point< float,2 >,itk::VectorContainer< unsigned long long,itk::Point< float,2 > >, std::set< unsigned long long > >'),
  ('CellInterface', 'itk::CellInterface', 'itkCellInterfaceUSCTI2FFULLULLULLPF2MCULLPF2', False, 'unsigned short,itk::CellTraitsInfo< 2,float,float,unsigned long long,unsigned long long,unsigned long long,itk::Point< float,2 >,itk::MapContainer< unsigned long long,itk::Point< float,2 > >, std::set< unsigned long long > >'),
  ('CellInterface', 'itk::CellInterface', 'itkCellInterfaceUSCTI2FFULLULLULLPF2VCULLPF2', False, 'unsigned short,itk::CellTraitsInfo< 2,float,float,unsigned long long,unsigned long long,unsigned long long,itk::Point< float,2 >,itk::VectorContainer< unsigned long long,itk::Point< float,2 > >, std::set< unsigned long long > >'),
  ('CellInterface', 'itk::CellInterface', 'itkCellInterfaceFCTI2FFULLULLULLPF2MCULLPF2', False, 'float,itk::CellTraitsInfo< 2,float,float,unsigned long long,unsigned long long,unsigned long long,itk::Point< float,2 >,itk::MapContainer< unsigned long long,itk::Point< float,2 > >, std::set< unsigned long long > >'),
  ('CellInterface', 'itk::CellInterface', 'itkCellInterfaceFCTI2FFULLULLULLPF2VCULLPF2', False, 'float,itk::CellTraitsInfo< 2,float,float,unsigned long long,unsigned long long,unsigned long long,itk::Point< float,2 >,itk::VectorContainer< unsigned long long,itk::Point< float,2 > >, std::set< unsigned long long > >'),
  ('CellInterface', 'itk::CellInterface', 'itkCellInterfaceDCTI2FFULLULLULLPF2MCULLPF2', False, 'double,itk::CellTraitsInfo< 2,float,float,unsigned long long,unsigned long long,unsigned long long,itk::Point< float,2 >,itk::MapContainer< unsigned long long,itk::Point< float,2 > >, std::set< unsigned long long > >'),
  ('CellInterface', 'itk::CellInterface', 'itkCellInterfaceDCTI2FFULLULLULLPF2VCULLPF2', False, 'double,itk::CellTraitsInfo< 2,float,float,unsigned long long,unsigned long long,unsigned long long,itk::Point< float,2 >,itk::VectorContainer< unsigned long long,itk::Point< float,2 > >, std::set< unsigned long long > >'),
  ('CellInterface', 'itk::CellInterface', 'itkCellInterfaceSSCTI3FFULLULLULLPF3MCULLPF3', False, 'signed short,itk::CellTraitsInfo< 3,float,float,unsigned long long,unsigned long long,unsigned long long,itk::Point< float,3 >,itk::MapContainer< unsigned long long,itk::Point< float,3 > >, std::set< unsigned long long > >'),
  ('CellInterface', 'itk::CellInterface', 'itkCellInterfaceSSCTI3FFULLULLULLPF3VCULLPF3', False, 'signed short,itk::CellTraitsInfo< 3,float,float,unsigned long long,unsigned long long,unsigned long long,itk::Point< float,3 >,itk::VectorContainer< unsigned long long,itk::Point< float,3 > >, std::set< unsigned long long > >'),
  ('CellInterface', 'itk::CellInterface', 'itkCellInterfaceUCCTI3FFULLULLULLPF3MCULLPF3', False, 'unsigned char,itk::CellTraitsInfo< 3,float,float,unsigned long long,unsigned long long,unsigned long long,itk::Point< float,3 >,itk::MapContainer< unsigned long long,itk::Point< float,3 > >, std::set< unsigned long long > >'),
  ('CellInterface', 'itk::CellInterface', 'itkCellInterfaceUCCTI3FFULLULLULLPF3VCULLPF3', False, 'unsigned char,itk::CellTraitsInfo< 3,float,float,unsigned long long,unsigned long long,unsigned long long,itk::Point< float,3 >,itk::VectorContainer< unsigned long long,itk::Point< float,3 > >, std::set< unsigned long long > >'),
  ('CellInterface', 'itk::CellInterface', 'itkCellInterfaceUSCTI3FFULLULLULLPF3MCULLPF3', False, 'unsigned short,itk::CellTraitsInfo< 3,float,float,unsigned long long,unsigned long long,unsigned long long,itk::Point< float,3 >,itk::MapContainer< unsigned long long,itk::Point< float,3 > >, std::set< unsigned long long > >'),
  ('CellInterface', 'itk::CellInterface', 'itkCellInterfaceUSCTI3FFULLULLULLPF3VCULLPF3', False, 'unsigned short,itk::CellTraitsInfo< 3,float,float,unsigned long long,unsigned long long,unsigned long long,itk::Point< float,3 >,itk::VectorContainer< unsigned long long,itk::Point< float,3 > >, std::set< unsigned long long > >'),
  ('CellInterface', 'itk::CellInterface', 'itkCellInterfaceFCTI3FFULLULLULLPF3MCULLPF3', False, 'float,itk::CellTraitsInfo< 3,float,float,unsigned long long,unsigned long long,unsigned long long,itk::Point< float,3 >,itk::MapContainer< unsigned long long,itk::Point< float,3 > >, std::set< unsigned long long > >'),
  ('CellInterface', 'itk::CellInterface', 'itkCellInterfaceFCTI3FFULLULLULLPF3VCULLPF3', False, 'float,itk::CellTraitsInfo< 3,float,float,unsigned long long,unsigned long long,unsigned long long,itk::Point< float,3 >,itk::VectorContainer< unsigned long long,itk::Point< float,3 > >, std::set< unsigned long long > >'),
  ('CellInterface', 'itk::CellInterface', 'itkCellInterfaceDCTI3FFULLULLULLPF3MCULLPF3', False, 'double,itk::CellTraitsInfo< 3,float,float,unsigned long long,unsigned long long,unsigned long long,itk::Point< float,3 >,itk::MapContainer< unsigned long long,itk::Point< float,3 > >, std::set< unsigned long long > >'),
  ('CellInterface', 'itk::CellInterface', 'itkCellInterfaceDCTI3FFULLULLULLPF3VCULLPF3', False, 'double,itk::CellTraitsInfo< 3,float,float,unsigned long long,unsigned long long,unsigned long long,itk::Point< float,3 >,itk::VectorContainer< unsigned long long,itk::Point< float,3 > >, std::set< unsigned long long > >'),
  ('MapContainer', 'itk::MapContainer', 'itkMapContainerULLCISSCTI2FFULLULLULLPF2MCULLPF2', False, 'unsigned long long, itk::CellInterface< signed short,itk::CellTraitsInfo< 2,float,float,unsigned long long,unsigned long long,unsigned long long,itk::Point< float,2 >,itk::MapContainer< unsigned long long,itk::Point< float,2 > >, std::set< unsigned long long > > > *'),
  ('MapContainer', 'itk::MapContainer', 'itkMapContainerULLCIUCCTI2FFULLULLULLPF2MCULLPF2', False, 'unsigned long long, itk::CellInterface< unsigned char,itk::CellTraitsInfo< 2,float,float,unsigned long long,unsigned long long,unsigned long long,itk::Point< float,2 >,itk::MapContainer< unsigned long long,itk::Point< float,2 > >, std::set< unsigned long long > > > *'),
  ('MapContainer', 'itk::MapContainer', 'itkMapContainerULLCIUSCTI2FFULLULLULLPF2MCULLPF2', False, 'unsigned long long, itk::CellInterface< unsigned short,itk::CellTraitsInfo< 2,float,float,unsigned long long,unsigned long long,unsigned long long,itk::Point< float,2 >,itk::MapContainer< unsigned long long,itk::Point< float,2 > >, std::set< unsigned long long > > > *'),
  ('MapContainer', 'itk::MapContainer', 'itkMapContainerULLCIFCTI2FFULLULLULLPF2MCULLPF2', False, 'unsigned long long, itk::CellInterface< float,itk::CellTraitsInfo< 2,float,float,unsigned long long,unsigned long long,unsigned long long,itk::Point< float,2 >,itk::MapContainer< unsigned long long,itk::Point< float,2 > >, std::set< unsigned long long > > > *'),
  ('MapContainer', 'itk::MapContainer', 'itkMapContainerULLCIDCTI2FFULLULLULLPF2MCULLPF2', False, 'unsigned long long, itk::CellInterface< double,itk::CellTraitsInfo< 2,float,float,unsigned long long,unsigned long long,unsigned long long,itk::Point< float,2 >,itk::MapContainer< unsigned long long,itk::Point< float,2 > >, std::set< unsigned long long > > > *'),
  ('MapContainer', 'itk::MapContainer', 'itkMapContainerULLCISSCTI3FFULLULLULLPF3MCULLPF3', False, 'unsigned long long, itk::CellInterface< signed short,itk::CellTraitsInfo< 3,float,float,unsigned long long,unsigned long long,unsigned long long,itk::Point< float,3 >,itk::MapContainer< unsigned long long,itk::Point< float,3 > >, std::set< unsigned long long > > > *'),
  ('MapContainer', 'itk::MapContainer', 'itkMapContainerULLCIUCCTI3FFULLULLULLPF3MCULLPF3', False, 'unsigned long long, itk::CellInterface< unsigned char,itk::CellTraitsInfo< 3,float,float,unsigned long long,unsigned long long,unsigned long long,itk::Point< float,3 >,itk::MapContainer< unsigned long long,itk::Point< float,3 > >, std::set< unsigned long long > > > *'),
  ('MapContainer', 'itk::MapContainer', 'itkMapContainerULLCIUSCTI3FFULLULLULLPF3MCULLPF3', False, 'unsigned long long, itk::CellInterface< unsigned short,itk::CellTraitsInfo< 3,float,float,unsigned long long,unsigned long long,unsigned long long,itk::Point< float,3 >,itk::MapContainer< unsigned long long,itk::Point< float,3 > >, std::set< unsigned long long > > > *'),
  ('MapContainer', 'itk::MapContainer', 'itkMapContainerULLCIFCTI3FFULLULLULLPF3MCULLPF3', False, 'unsigned long long, itk::CellInterface< float,itk::CellTraitsInfo< 3,float,float,unsigned long long,unsigned long long,unsigned long long,itk::Point< float,3 >,itk::MapContainer< unsigned long long,itk::Point< float,3 > >, std::set< unsigned long long > > > *'),
  ('MapContainer', 'itk::MapContainer', 'itkMapContainerULLCIDCTI3FFULLULLULLPF3MCULLPF3', False, 'unsigned long long, itk::CellInterface< double,itk::CellTraitsInfo< 3,float,float,unsigned long long,unsigned long long,unsigned long long,itk::Point< float,3 >,itk::MapContainer< unsigned long long,itk::Point< float,3 > >, std::set< unsigned long long > > > *'),
  ('VectorContainer', 'itk::VectorContainer', 'itkVectorContainerULLCISSCTI2FFULLULLULLPF2VCULLPF2', False, 'unsigned long long, itk::CellInterface< signed short,itk::CellTraitsInfo< 2,float,float,unsigned long long,unsigned long long,unsigned long long,itk::Point< float,2 >,itk::VectorContainer< unsigned long long,itk::Point< float,2 > >, std::set< unsigned long long > > > *'),
  ('VectorContainer', 'itk::VectorContainer', 'itkVectorContainerULLCIUCCTI2FFULLULLULLPF2VCULLPF2', False, 'unsigned long long, itk::CellInterface< unsigned char,itk::CellTraitsInfo< 2,float,float,unsigned long long,unsigned long long,unsigned long long,itk::Point< float,2 >,itk::VectorContainer< unsigned long long,itk::Point< float,2 > >, std::set< unsigned long long > > > *'),
  ('VectorContainer', 'itk::VectorContainer', 'itkVectorContainerULLCIUSCTI2FFULLULLULLPF2VCULLPF2', False, 'unsigned long long, itk::CellInterface< unsigned short,itk::CellTraitsInfo< 2,float,float,unsigned long long,unsigned long long,unsigned long long,itk::Point< float,2 >,itk::VectorContainer< unsigned long long,itk::Point< float,2 > >, std::set< unsigned long long > > > *'),
  ('VectorContainer', 'itk::VectorContainer', 'itkVectorContainerULLCIFCTI2FFULLULLULLPF2VCULLPF2', False, 'unsigned long long, itk::CellInterface< float,itk::CellTraitsInfo< 2,float,float,unsigned long long,unsigned long long,unsigned long long,itk::Point< float,2 >,itk::VectorContainer< unsigned long long,itk::Point< float,2 > >, std::set< unsigned long long > > > *'),
  ('VectorContainer', 'itk::VectorContainer', 'itkVectorContainerULLCIDCTI2FFULLULLULLPF2VCULLPF2', False, 'unsigned long long, itk::CellInterface< double,itk::CellTraitsInfo< 2,float,float,unsigned long long,unsigned long long,unsigned long long,itk::Point< float,2 >,itk::VectorContainer< unsigned long long,itk::Point< float,2 > >, std::set< unsigned long long > > > *'),
  ('VectorContainer', 'itk::VectorContainer', 'itkVectorContainerULLCISSCTI3FFULLULLULLPF3VCULLPF3', False, 'unsigned long long, itk::CellInterface< signed short,itk::CellTraitsInfo< 3,float,float,unsigned long long,unsigned long long,unsigned long long,itk::Point< float,3 >,itk::VectorContainer< unsigned long long,itk::Point< float,3 > >, std::set< unsigned long long > > > *'),
  ('VectorContainer', 'itk::VectorContainer', 'itkVectorContainerULLCIUCCTI3FFULLULLULLPF3VCULLPF3', False, 'unsigned long long, itk::CellInterface< unsigned char,itk::CellTraitsInfo< 3,float,float,unsigned long long,unsigned long long,unsigned long long,itk::Point< float,3 >,itk::VectorContainer< unsigned long long,itk::Point< float,3 > >, std::set< unsigned long long > > > *'),
  ('VectorContainer', 'itk::VectorContainer', 'itkVectorContainerULLCIUSCTI3FFULLULLULLPF3VCULLPF3', False, 'unsigned long long, itk::CellInterface< unsigned short,itk::CellTraitsInfo< 3,float,float,unsigned long long,unsigned long long,unsigned long long,itk::Point< float,3 >,itk::VectorContainer< unsigned long long,itk::Point< float,3 > >, std::set< unsigned long long > > > *'),
  ('VectorContainer', 'itk::VectorContainer', 'itkVectorContainerULLCIFCTI3FFULLULLULLPF3VCULLPF3', False, 'unsigned long long, itk::CellInterface< float,itk::CellTraitsInfo< 3,float,float,unsigned long long,unsigned long long,unsigned long long,itk::Point< float,3 >,itk::VectorContainer< unsigned long long,itk::Point< float,3 > >, std::set< unsigned long long > > > *'),
  ('VectorContainer', 'itk::VectorContainer', 'itkVectorContainerULLCIDCTI3FFULLULLULLPF3VCULLPF3', False, 'unsigned long long, itk::CellInterface< double,itk::CellTraitsInfo< 3,float,float,unsigned long long,unsigned long long,unsigned long long,itk::Point< float,3 >,itk::VectorContainer< unsigned long long,itk::Point< float,3 > >, std::set< unsigned long long > > > *'),
  ('CellInterfaceVisitor', 'itk::CellInterfaceVisitor', 'itkCellInterfaceVisitorSSCTI2FFULLULLULLPF2MCULLPF2', False, 'signed short, itk::CellTraitsInfo< 2,float,float,unsigned long long,unsigned long long,unsigned long long,itk::Point< float,2 >,itk::MapContainer< unsigned long long,itk::Point< float,2 > >, std::set< unsigned long long > > '),
  ('CellInterfaceVisitor', 'itk::CellInterfaceVisitor', 'itkCellInterfaceVisitorUCCTI2FFULLULLULLPF2MCULLPF2', False, 'unsigned char, itk::CellTraitsInfo< 2,float,float,unsigned long long,unsigned long long,unsigned long long,itk::Point< float,2 >,itk::MapContainer< unsigned long long,itk::Point< float,2 > >, std::set< unsigned long long > > '),
  ('CellInterfaceVisitor', 'itk::CellInterfaceVisitor', 'itkCellInterfaceVisitorUSCTI2FFULLULLULLPF2MCULLPF2', False, 'unsigned short, itk::CellTraitsInfo< 2,float,float,unsigned long long,unsigned long long,unsigned long long,itk::Point< float,2 >,itk::MapContainer< unsigned long long,itk::Point< float,2 > >, std::set< unsigned long long > > '),
  ('CellInterfaceVisitor', 'itk::CellInterfaceVisitor', 'itkCellInterfaceVisitorFCTI2FFULLULLULLPF2MCULLPF2', False, 'float, itk::CellTraitsInfo< 2,float,float,unsigned long long,unsigned long long,unsigned long long,itk::Point< float,2 >,itk::MapContainer< unsigned long long,itk::Point< float,2 > >, std::set< unsigned long long > > '),
  ('CellInterfaceVisitor', 'itk::CellInterfaceVisitor', 'itkCellInterfaceVisitorDCTI2FFULLULLULLPF2MCULLPF2', False, 'double, itk::CellTraitsInfo< 2,float,float,unsigned long long,unsigned long long,unsigned long long,itk::Point< float,2 >,itk::MapContainer< unsigned long long,itk::Point< float,2 > >, std::set< unsigned long long > > '),
  ('CellInterfaceVisitor', 'itk::CellInterfaceVisitor', 'itkCellInterfaceVisitorSSCTI3FFULLULLULLPF3MCULLPF3', False, 'signed short, itk::CellTraitsInfo< 3,float,float,unsigned long long,unsigned long long,unsigned long long,itk::Point< float,3 >,itk::MapContainer< unsigned long long,itk::Point< float,3 > >, std::set< unsigned long long > > '),
  ('CellInterfaceVisitor', 'itk::CellInterfaceVisitor', 'itkCellInterfaceVisitorUCCTI3FFULLULLULLPF3MCULLPF3', False, 'unsigned char, itk::CellTraitsInfo< 3,float,float,unsigned long long,unsigned long long,unsigned long long,itk::Point< float,3 >,itk::MapContainer< unsigned long long,itk::Point< float,3 > >, std::set< unsigned long long > > '),
  ('CellInterfaceVisitor', 'itk::CellInterfaceVisitor', 'itkCellInterfaceVisitorUSCTI3FFULLULLULLPF3MCULLPF3', False, 'unsigned short, itk::CellTraitsInfo< 3,float,float,unsigned long long,unsigned long long,unsigned long long,itk::Point< float,3 >,itk::MapContainer< unsigned long long,itk::Point< float,3 > >, std::set< unsigned long long > > '),
  ('CellInterfaceVisitor', 'itk::CellInterfaceVisitor', 'itkCellInterfaceVisitorFCTI3FFULLULLULLPF3MCULLPF3', False, 'float, itk::CellTraitsInfo< 3,float,float,unsigned long long,unsigned long long,unsigned long long,itk::Point< float,3 >,itk::MapContainer< unsigned long long,itk::Point< float,3 > >, std::set< unsigned long long > > '),
  ('CellInterfaceVisitor', 'itk::CellInterfaceVisitor', 'itkCellInterfaceVisitorDCTI3FFULLULLULLPF3MCULLPF3', False, 'double, itk::CellTraitsInfo< 3,float,float,unsigned long long,unsigned long long,unsigned long long,itk::Point< float,3 >,itk::MapContainer< unsigned long long,itk::Point< float,3 > >, std::set< unsigned long long > > '),
  ('MeshSource', 'itk::MeshSource', 'itkMeshSourcePSSS2', True, 'itk::PointSet< signed short,2 >'),
  ('MeshSource', 'itk::MeshSource', 'itkMeshSourceMSS2', True, 'itk::Mesh< signed short,2 >'),
  ('MeshSource', 'itk::MeshSource', 'itkMeshSourcePSUC2', True, 'itk::PointSet< unsigned char,2 >'),
  ('MeshSource', 'itk::MeshSource', 'itkMeshSourceMUC2', True, 'itk::Mesh< unsigned char,2 >'),
  ('MeshSource', 'itk::MeshSource', 'itkMeshSourcePSUS2', True, 'itk::PointSet< unsigned short,2 >'),
  ('MeshSource', 'itk::MeshSource', 'itkMeshSourceMUS2', True, 'itk::Mesh< unsigned short,2 >'),
  ('MeshSource', 'itk::MeshSource', 'itkMeshSourcePSF2', True, 'itk::PointSet< float,2 >'),
  ('MeshSource', 'itk::MeshSource', 'itkMeshSourceMF2', True, 'itk::Mesh< float,2 >'),
  ('MeshSource', 'itk::MeshSource', 'itkMeshSourcePSD2', True, 'itk::PointSet< double,2 >'),
  ('MeshSource', 'itk::MeshSource', 'itkMeshSourceMD2', True, 'itk::Mesh< double,2 >'),
  ('MeshSource', 'itk::MeshSource', 'itkMeshSourcePSSS3', True, 'itk::PointSet< signed short,3 >'),
  ('MeshSource', 'itk::MeshSource', 'itkMeshSourceMSS3', True, 'itk::Mesh< signed short,3 >'),
  ('MeshSource', 'itk::MeshSource', 'itkMeshSourcePSUC3', True, 'itk::PointSet< unsigned char,3 >'),
  ('MeshSource', 'itk::MeshSource', 'itkMeshSourceMUC3', True, 'itk::Mesh< unsigned char,3 >'),
  ('MeshSource', 'itk::MeshSource', 'itkMeshSourcePSUS3', True, 'itk::PointSet< unsigned short,3 >'),
  ('MeshSource', 'itk::MeshSource', 'itkMeshSourceMUS3', True, 'itk::Mesh< unsigned short,3 >'),
  ('MeshSource', 'itk::MeshSource', 'itkMeshSourcePSF3', True, 'itk::PointSet< float,3 >'),
  ('MeshSource', 'itk::MeshSource', 'itkMeshSourceMF3', True, 'itk::Mesh< float,3 >'),
  ('MeshSource', 'itk::MeshSource', 'itkMeshSourcePSD3', True, 'itk::PointSet< double,3 >'),
  ('MeshSource', 'itk::MeshSource', 'itkMeshSourceMD3', True, 'itk::Mesh< double,3 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterISS2MSS2', True, 'itk::Image< signed short,2 >, itk::Mesh< signed short,2 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterISS2PSSS2', True, 'itk::Image< signed short,2 >, itk::PointSet< signed short,2 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterISS2MUC2', True, 'itk::Image< signed short,2 >, itk::Mesh< unsigned char,2 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterISS2PSUC2', True, 'itk::Image< signed short,2 >, itk::PointSet< unsigned char,2 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterISS2MUS2', True, 'itk::Image< signed short,2 >, itk::Mesh< unsigned short,2 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterISS2PSUS2', True, 'itk::Image< signed short,2 >, itk::PointSet< unsigned short,2 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterISS2MF2', True, 'itk::Image< signed short,2 >, itk::Mesh< float,2 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterISS2PSF2', True, 'itk::Image< signed short,2 >, itk::PointSet< float,2 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterISS2MD2', True, 'itk::Image< signed short,2 >, itk::Mesh< double,2 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterISS2PSD2', True, 'itk::Image< signed short,2 >, itk::PointSet< double,2 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterIUC2MSS2', True, 'itk::Image< unsigned char,2 >, itk::Mesh< signed short,2 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterIUC2PSSS2', True, 'itk::Image< unsigned char,2 >, itk::PointSet< signed short,2 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterIUC2MUC2', True, 'itk::Image< unsigned char,2 >, itk::Mesh< unsigned char,2 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterIUC2PSUC2', True, 'itk::Image< unsigned char,2 >, itk::PointSet< unsigned char,2 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterIUC2MUS2', True, 'itk::Image< unsigned char,2 >, itk::Mesh< unsigned short,2 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterIUC2PSUS2', True, 'itk::Image< unsigned char,2 >, itk::PointSet< unsigned short,2 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterIUC2MF2', True, 'itk::Image< unsigned char,2 >, itk::Mesh< float,2 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterIUC2PSF2', True, 'itk::Image< unsigned char,2 >, itk::PointSet< float,2 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterIUC2MD2', True, 'itk::Image< unsigned char,2 >, itk::Mesh< double,2 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterIUC2PSD2', True, 'itk::Image< unsigned char,2 >, itk::PointSet< double,2 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterIUS2MSS2', True, 'itk::Image< unsigned short,2 >, itk::Mesh< signed short,2 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterIUS2PSSS2', True, 'itk::Image< unsigned short,2 >, itk::PointSet< signed short,2 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterIUS2MUC2', True, 'itk::Image< unsigned short,2 >, itk::Mesh< unsigned char,2 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterIUS2PSUC2', True, 'itk::Image< unsigned short,2 >, itk::PointSet< unsigned char,2 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterIUS2MUS2', True, 'itk::Image< unsigned short,2 >, itk::Mesh< unsigned short,2 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterIUS2PSUS2', True, 'itk::Image< unsigned short,2 >, itk::PointSet< unsigned short,2 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterIUS2MF2', True, 'itk::Image< unsigned short,2 >, itk::Mesh< float,2 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterIUS2PSF2', True, 'itk::Image< unsigned short,2 >, itk::PointSet< float,2 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterIUS2MD2', True, 'itk::Image< unsigned short,2 >, itk::Mesh< double,2 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterIUS2PSD2', True, 'itk::Image< unsigned short,2 >, itk::PointSet< double,2 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterIF2MSS2', True, 'itk::Image< float,2 >, itk::Mesh< signed short,2 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterIF2PSSS2', True, 'itk::Image< float,2 >, itk::PointSet< signed short,2 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterIF2MUC2', True, 'itk::Image< float,2 >, itk::Mesh< unsigned char,2 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterIF2PSUC2', True, 'itk::Image< float,2 >, itk::PointSet< unsigned char,2 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterIF2MUS2', True, 'itk::Image< float,2 >, itk::Mesh< unsigned short,2 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterIF2PSUS2', True, 'itk::Image< float,2 >, itk::PointSet< unsigned short,2 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterIF2MF2', True, 'itk::Image< float,2 >, itk::Mesh< float,2 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterIF2PSF2', True, 'itk::Image< float,2 >, itk::PointSet< float,2 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterIF2MD2', True, 'itk::Image< float,2 >, itk::Mesh< double,2 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterIF2PSD2', True, 'itk::Image< float,2 >, itk::PointSet< double,2 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterID2MSS2', True, 'itk::Image< double,2 >, itk::Mesh< signed short,2 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterID2PSSS2', True, 'itk::Image< double,2 >, itk::PointSet< signed short,2 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterID2MUC2', True, 'itk::Image< double,2 >, itk::Mesh< unsigned char,2 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterID2PSUC2', True, 'itk::Image< double,2 >, itk::PointSet< unsigned char,2 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterID2MUS2', True, 'itk::Image< double,2 >, itk::Mesh< unsigned short,2 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterID2PSUS2', True, 'itk::Image< double,2 >, itk::PointSet< unsigned short,2 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterID2MF2', True, 'itk::Image< double,2 >, itk::Mesh< float,2 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterID2PSF2', True, 'itk::Image< double,2 >, itk::PointSet< float,2 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterID2MD2', True, 'itk::Image< double,2 >, itk::Mesh< double,2 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterID2PSD2', True, 'itk::Image< double,2 >, itk::PointSet< double,2 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterISS3MSS3', True, 'itk::Image< signed short,3 >, itk::Mesh< signed short,3 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterISS3PSSS3', True, 'itk::Image< signed short,3 >, itk::PointSet< signed short,3 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterISS3MUC3', True, 'itk::Image< signed short,3 >, itk::Mesh< unsigned char,3 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterISS3PSUC3', True, 'itk::Image< signed short,3 >, itk::PointSet< unsigned char,3 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterISS3MUS3', True, 'itk::Image< signed short,3 >, itk::Mesh< unsigned short,3 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterISS3PSUS3', True, 'itk::Image< signed short,3 >, itk::PointSet< unsigned short,3 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterISS3MF3', True, 'itk::Image< signed short,3 >, itk::Mesh< float,3 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterISS3PSF3', True, 'itk::Image< signed short,3 >, itk::PointSet< float,3 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterISS3MD3', True, 'itk::Image< signed short,3 >, itk::Mesh< double,3 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterISS3PSD3', True, 'itk::Image< signed short,3 >, itk::PointSet< double,3 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterIUC3MSS3', True, 'itk::Image< unsigned char,3 >, itk::Mesh< signed short,3 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterIUC3PSSS3', True, 'itk::Image< unsigned char,3 >, itk::PointSet< signed short,3 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterIUC3MUC3', True, 'itk::Image< unsigned char,3 >, itk::Mesh< unsigned char,3 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterIUC3PSUC3', True, 'itk::Image< unsigned char,3 >, itk::PointSet< unsigned char,3 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterIUC3MUS3', True, 'itk::Image< unsigned char,3 >, itk::Mesh< unsigned short,3 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterIUC3PSUS3', True, 'itk::Image< unsigned char,3 >, itk::PointSet< unsigned short,3 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterIUC3MF3', True, 'itk::Image< unsigned char,3 >, itk::Mesh< float,3 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterIUC3PSF3', True, 'itk::Image< unsigned char,3 >, itk::PointSet< float,3 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterIUC3MD3', True, 'itk::Image< unsigned char,3 >, itk::Mesh< double,3 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterIUC3PSD3', True, 'itk::Image< unsigned char,3 >, itk::PointSet< double,3 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterIUS3MSS3', True, 'itk::Image< unsigned short,3 >, itk::Mesh< signed short,3 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterIUS3PSSS3', True, 'itk::Image< unsigned short,3 >, itk::PointSet< signed short,3 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterIUS3MUC3', True, 'itk::Image< unsigned short,3 >, itk::Mesh< unsigned char,3 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterIUS3PSUC3', True, 'itk::Image< unsigned short,3 >, itk::PointSet< unsigned char,3 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterIUS3MUS3', True, 'itk::Image< unsigned short,3 >, itk::Mesh< unsigned short,3 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterIUS3PSUS3', True, 'itk::Image< unsigned short,3 >, itk::PointSet< unsigned short,3 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterIUS3MF3', True, 'itk::Image< unsigned short,3 >, itk::Mesh< float,3 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterIUS3PSF3', True, 'itk::Image< unsigned short,3 >, itk::PointSet< float,3 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterIUS3MD3', True, 'itk::Image< unsigned short,3 >, itk::Mesh< double,3 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterIUS3PSD3', True, 'itk::Image< unsigned short,3 >, itk::PointSet< double,3 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterIF3MSS3', True, 'itk::Image< float,3 >, itk::Mesh< signed short,3 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterIF3PSSS3', True, 'itk::Image< float,3 >, itk::PointSet< signed short,3 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterIF3MUC3', True, 'itk::Image< float,3 >, itk::Mesh< unsigned char,3 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterIF3PSUC3', True, 'itk::Image< float,3 >, itk::PointSet< unsigned char,3 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterIF3MUS3', True, 'itk::Image< float,3 >, itk::Mesh< unsigned short,3 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterIF3PSUS3', True, 'itk::Image< float,3 >, itk::PointSet< unsigned short,3 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterIF3MF3', True, 'itk::Image< float,3 >, itk::Mesh< float,3 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterIF3PSF3', True, 'itk::Image< float,3 >, itk::PointSet< float,3 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterIF3MD3', True, 'itk::Image< float,3 >, itk::Mesh< double,3 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterIF3PSD3', True, 'itk::Image< float,3 >, itk::PointSet< double,3 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterID3MSS3', True, 'itk::Image< double,3 >, itk::Mesh< signed short,3 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterID3PSSS3', True, 'itk::Image< double,3 >, itk::PointSet< signed short,3 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterID3MUC3', True, 'itk::Image< double,3 >, itk::Mesh< unsigned char,3 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterID3PSUC3', True, 'itk::Image< double,3 >, itk::PointSet< unsigned char,3 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterID3MUS3', True, 'itk::Image< double,3 >, itk::Mesh< unsigned short,3 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterID3PSUS3', True, 'itk::Image< double,3 >, itk::PointSet< unsigned short,3 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterID3MF3', True, 'itk::Image< double,3 >, itk::Mesh< float,3 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterID3PSF3', True, 'itk::Image< double,3 >, itk::PointSet< float,3 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterID3MD3', True, 'itk::Image< double,3 >, itk::Mesh< double,3 >'),
  ('ImageToMeshFilter', 'itk::ImageToMeshFilter', 'itkImageToMeshFilterID3PSD3', True, 'itk::Image< double,3 >, itk::PointSet< double,3 >'),
  ('MeshToMeshFilter', 'itk::MeshToMeshFilter', 'itkMeshToMeshFilterMF2MF2', True, 'itk::Mesh< float,2 >, itk::Mesh< float,2 >'),
  ('MeshToMeshFilter', 'itk::MeshToMeshFilter', 'itkMeshToMeshFilterMD2MD2', True, 'itk::Mesh< double,2 >, itk::Mesh< double,2 >'),
  ('MeshToMeshFilter', 'itk::MeshToMeshFilter', 'itkMeshToMeshFilterMF3MF3', True, 'itk::Mesh< float,3 >, itk::Mesh< float,3 >'),
  ('MeshToMeshFilter', 'itk::MeshToMeshFilter', 'itkMeshToMeshFilterMD3MD3', True, 'itk::Mesh< double,3 >, itk::Mesh< double,3 >'),
  ('VTKPolyDataReader', 'itk::VTKPolyDataReader', 'itkVTKPolyDataReaderMF2', True, 'itk::Mesh< float,2 >'),
  ('VTKPolyDataReader', 'itk::VTKPolyDataReader', 'itkVTKPolyDataReaderMD2', True, 'itk::Mesh< double,2 >'),
  ('VTKPolyDataReader', 'itk::VTKPolyDataReader', 'itkVTKPolyDataReaderMF3', True, 'itk::Mesh< float,3 >'),
  ('VTKPolyDataReader', 'itk::VTKPolyDataReader', 'itkVTKPolyDataReaderMD3', True, 'itk::Mesh< double,3 >'),
  ('VTKPolyDataWriter', 'itk::VTKPolyDataWriter', 'itkVTKPolyDataWriterMF2', True, 'itk::Mesh<float,2 >'),
  ('VTKPolyDataWriter', 'itk::VTKPolyDataWriter', 'itkVTKPolyDataWriterMD2', True, 'itk::Mesh<double,2 >'),
  ('VTKPolyDataWriter', 'itk::VTKPolyDataWriter', 'itkVTKPolyDataWriterMF3', True, 'itk::Mesh<float,3 >'),
  ('VTKPolyDataWriter', 'itk::VTKPolyDataWriter', 'itkVTKPolyDataWriterMD3', True, 'itk::Mesh<double,3 >'),
  ('BinaryMask3DMeshSource', 'itk::BinaryMask3DMeshSource', 'itkBinaryMask3DMeshSourceISS3MSS3', True, 'itk::Image< signed short,3 >, itk::Mesh< signed short,3 >'),
  ('BinaryMask3DMeshSource', 'itk::BinaryMask3DMeshSource', 'itkBinaryMask3DMeshSourceISS3MUC3', True, 'itk::Image< signed short,3 >, itk::Mesh< unsigned char,3 >'),
  ('BinaryMask3DMeshSource', 'itk::BinaryMask3DMeshSource', 'itkBinaryMask3DMeshSourceISS3MUS3', True, 'itk::Image< signed short,3 >, itk::Mesh< unsigned short,3 >'),
  ('BinaryMask3DMeshSource', 'itk::BinaryMask3DMeshSource', 'itkBinaryMask3DMeshSourceISS3MF3', True, 'itk::Image< signed short,3 >, itk::Mesh< float,3 >'),
  ('BinaryMask3DMeshSource', 'itk::BinaryMask3DMeshSource', 'itkBinaryMask3DMeshSourceISS3MD3', True, 'itk::Image< signed short,3 >, itk::Mesh< double,3 >'),
  ('BinaryMask3DMeshSource', 'itk::BinaryMask3DMeshSource', 'itkBinaryMask3DMeshSourceIUC3MSS3', True, 'itk::Image< unsigned char,3 >, itk::Mesh< signed short,3 >'),
  ('BinaryMask3DMeshSource', 'itk::BinaryMask3DMeshSource', 'itkBinaryMask3DMeshSourceIUC3MUC3', True, 'itk::Image< unsigned char,3 >, itk::Mesh< unsigned char,3 >'),
  ('BinaryMask3DMeshSource', 'itk::BinaryMask3DMeshSource', 'itkBinaryMask3DMeshSourceIUC3MUS3', True, 'itk::Image< unsigned char,3 >, itk::Mesh< unsigned short,3 >'),
  ('BinaryMask3DMeshSource', 'itk::BinaryMask3DMeshSource', 'itkBinaryMask3DMeshSourceIUC3MF3', True, 'itk::Image< unsigned char,3 >, itk::Mesh< float,3 >'),
  ('BinaryMask3DMeshSource', 'itk::BinaryMask3DMeshSource', 'itkBinaryMask3DMeshSourceIUC3MD3', True, 'itk::Image< unsigned char,3 >, itk::Mesh< double,3 >'),
  ('BinaryMask3DMeshSource', 'itk::BinaryMask3DMeshSource', 'itkBinaryMask3DMeshSourceIUS3MSS3', True, 'itk::Image< unsigned short,3 >, itk::Mesh< signed short,3 >'),
  ('BinaryMask3DMeshSource', 'itk::BinaryMask3DMeshSource', 'itkBinaryMask3DMeshSourceIUS3MUC3', True, 'itk::Image< unsigned short,3 >, itk::Mesh< unsigned char,3 >'),
  ('BinaryMask3DMeshSource', 'itk::BinaryMask3DMeshSource', 'itkBinaryMask3DMeshSourceIUS3MUS3', True, 'itk::Image< unsigned short,3 >, itk::Mesh< unsigned short,3 >'),
  ('BinaryMask3DMeshSource', 'itk::BinaryMask3DMeshSource', 'itkBinaryMask3DMeshSourceIUS3MF3', True, 'itk::Image< unsigned short,3 >, itk::Mesh< float,3 >'),
  ('BinaryMask3DMeshSource', 'itk::BinaryMask3DMeshSource', 'itkBinaryMask3DMeshSourceIUS3MD3', True, 'itk::Image< unsigned short,3 >, itk::Mesh< double,3 >'),
  ('ConnectedRegionsMeshFilter', 'itk::ConnectedRegionsMeshFilter', 'itkConnectedRegionsMeshFilterMF2MF2', True, 'itk::Mesh< float,2 >, itk::Mesh< float,2 >'),
  ('ConnectedRegionsMeshFilter', 'itk::ConnectedRegionsMeshFilter', 'itkConnectedRegionsMeshFilterMD2MD2', True, 'itk::Mesh< double,2 >, itk::Mesh< double,2 >'),
  ('ConnectedRegionsMeshFilter', 'itk::ConnectedRegionsMeshFilter', 'itkConnectedRegionsMeshFilterMF3MF3', True, 'itk::Mesh< float,3 >, itk::Mesh< float,3 >'),
  ('ConnectedRegionsMeshFilter', 'itk::ConnectedRegionsMeshFilter', 'itkConnectedRegionsMeshFilterMD3MD3', True, 'itk::Mesh< double,3 >, itk::Mesh< double,3 >'),
  ('TransformMeshFilter', 'itk::TransformMeshFilter', 'itkTransformMeshFilterMF2MF2TD22', True, 'itk::Mesh< float,2 >, itk::Mesh< float,2 >, itk::Transform< double, 2, 2 >'),
  ('TransformMeshFilter', 'itk::TransformMeshFilter', 'itkTransformMeshFilterMF2MF2TF22', True, 'itk::Mesh< float,2 >, itk::Mesh< float,2 >, itk::Transform< float, 2, 2 >'),
  ('TransformMeshFilter', 'itk::TransformMeshFilter', 'itkTransformMeshFilterMD2MD2TD22', True, 'itk::Mesh< double,2 >, itk::Mesh< double,2 >, itk::Transform< double, 2, 2 >'),
  ('TransformMeshFilter', 'itk::TransformMeshFilter', 'itkTransformMeshFilterMD2MD2TF22', True, 'itk::Mesh< double,2 >, itk::Mesh< double,2 >, itk::Transform< float, 2, 2 >'),
  ('TransformMeshFilter', 'itk::TransformMeshFilter', 'itkTransformMeshFilterMF3MF3TD33', True, 'itk::Mesh< float,3 >, itk::Mesh< float,3 >, itk::Transform< double, 3, 3 >'),
  ('TransformMeshFilter', 'itk::TransformMeshFilter', 'itkTransformMeshFilterMF3MF3TF33', True, 'itk::Mesh< float,3 >, itk::Mesh< float,3 >, itk::Transform< float, 3, 3 >'),
  ('TransformMeshFilter', 'itk::TransformMeshFilter', 'itkTransformMeshFilterMD3MD3TD33', True, 'itk::Mesh< double,3 >, itk::Mesh< double,3 >, itk::Transform< double, 3, 3 >'),
  ('TransformMeshFilter', 'itk::TransformMeshFilter', 'itkTransformMeshFilterMD3MD3TF33', True, 'itk::Mesh< double,3 >, itk::Mesh< double,3 >, itk::Transform< float, 3, 3 >'),
  ('Point1D', 'itk::Point1D', 'itkPoint1D', False),
  ('TriangleMeshToBinaryImageFilter', 'itk::TriangleMeshToBinaryImageFilter', 'itkTriangleMeshToBinaryImageFilterMSS3ISS3', True, 'itk::Mesh< signed short,3 >, itk::Image< signed short,3 > '),
  ('TriangleMeshToBinaryImageFilter', 'itk::TriangleMeshToBinaryImageFilter', 'itkTriangleMeshToBinaryImageFilterMUC3IUC3', True, 'itk::Mesh< unsigned char,3 >, itk::Image< unsigned char,3 > '),
  ('TriangleMeshToBinaryImageFilter', 'itk::TriangleMeshToBinaryImageFilter', 'itkTriangleMeshToBinaryImageFilterMUS3IUS3', True, 'itk::Mesh< unsigned short,3 >, itk::Image< unsigned short,3 > '),
  ('TriangleMeshToBinaryImageFilter', 'itk::TriangleMeshToBinaryImageFilter', 'itkTriangleMeshToBinaryImageFilterMF3IF3', True, 'itk::Mesh< float,3 >, itk::Image< float,3 > '),
  ('TriangleMeshToBinaryImageFilter', 'itk::TriangleMeshToBinaryImageFilter', 'itkTriangleMeshToBinaryImageFilterMD3ID3', True, 'itk::Mesh< double,3 >, itk::Image< double,3 > '),
)
snake_case_functions = ('vtk_poly_data_reader', 'binary_mask3_d_mesh_source', 'mesh_source', 'mesh_to_mesh_filter', 'image_to_mesh_filter', 'triangle_mesh_to_binary_image_filter', 'transform_mesh_filter', 'connected_regions_mesh_filter', )
